==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/LD.R <==
"LD.geneSet" <- function( object )
  {

    ped<-geneSet2Ped2(object)

    tmp<-getLD(ped$ped,ped$columns, iprint=FALSE)

    D<-tmp$DMat
    rownames(D) <- object@markerInfo$Name
    colnames(D) <- object@markerInfo$Name

    Dprime<-tmp$DprimeMat
    rownames(Dprime) <- object@markerInfo$Name
    colnames(Dprime) <- object@markerInfo$Name

    corr<-tmp$rMat
    rownames(corr) <- object@markerInfo$Name
    colnames(corr) <- object@markerInfo$Name

    r.2<-tmp$r2Mat
    rownames(r.2) <- object@markerInfo$Name
    colnames(r.2) <- object@markerInfo$Name

    chisq<-tmp$chisqMat
    rownames(chisq) <- object@markerInfo$Name
    colnames(chisq) <- object@markerInfo$Name

    p.value<-tmp$pvalMat
    rownames(p.value) <- object@markerInfo$Name
    colnames(p.value) <- object@markerInfo$Name

    nobs<-tmp$nMat
    rownames(nobs) <- object@markerInfo$Name
    colnames(nobs) <- object@markerInfo$Name

    LOD<-tmp$LODMat
    rownames(LOD) <- object@markerInfo$Name
    colnames(LOD) <- object@markerInfo$Name



    retval <- new("LD",
                   call=match.call(),
                   "D"=D,
                   "D'"=Dprime,
                   "r" = corr,
                   "R^2" = r.2,
                   "n"=nobs,
                   "X^2"=chisq,
                   "P-value"=p.value,
                   "LOD"=LOD
           )
    retval
  }

setGeneric("LD", function(object, ...)
           standardGeneric("LD"))

setMethod("LD", "geneSet",    LD.geneSet)




geneSet2Ped2<-function (geneSetObject) 
{
    sampleInfo <- geneSetObject@sampleInfo
    len <- ncol(sampleInfo)
    if(len<1) {
        stop("`sampleInfo' must include at least 1 column")
    } 
    columns <- colnames(sampleInfo)
    geneInfo <- alleleCodes(geneSetObject)
    ped <- cbind(as.matrix(sampleInfo), geneInfo)
    invisible(list(ped = ped, columns = columns))
}

alleleCodes <- function(obj, which=c(1, 2))
{
  retval <- alleles(obj,which=which, codes=TRUE)
  retval[is.na(retval)] <- 0
  retval
}

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/LD.R <==
"LD.geneSet" <- function( object, pooling.threshold=0.1, founderOnly=FALSE, quiet=TRUE )
  {

    tmp<-getLD(object, pooling.threshold, founderOnly, quiet)

    D<-tmp$DMat
    rownames(D) <- object@markerInfo$Name
    colnames(D) <- object@markerInfo$Name

    Dprime<-tmp$DprimeMat
    rownames(Dprime) <- object@markerInfo$Name
    colnames(Dprime) <- object@markerInfo$Name

    corr<-tmp$rMat
    rownames(corr) <- object@markerInfo$Name
    colnames(corr) <- object@markerInfo$Name

    r.2<-tmp$r2Mat
    rownames(r.2) <- object@markerInfo$Name
    colnames(r.2) <- object@markerInfo$Name

    chisq<-tmp$chisqMat
    rownames(chisq) <- object@markerInfo$Name
    colnames(chisq) <- object@markerInfo$Name

    p.value<-tmp$pvalMat
    rownames(p.value) <- object@markerInfo$Name
    colnames(p.value) <- object@markerInfo$Name

    nobs<-tmp$nMat
    rownames(nobs) <- object@markerInfo$Name
    colnames(nobs) <- object@markerInfo$Name

    LOD<-tmp$LODMat
    rownames(LOD) <- object@markerInfo$Name
    colnames(LOD) <- object@markerInfo$Name



    retval <- new("LD",
                   call=match.call(),
                   "D"=D,
                   "D'"=Dprime,
                   "r" = corr,
                   "R^2" = r.2,
                   "n"=nobs,
                   "X^2"=chisq,
                   "P-value"=p.value,
                   "LOD"=LOD
           )
    retval
  }

setGeneric("LD", function(object, pooling.threshold=0.1, founderOnly=FALSE, quiet=TRUE)
           standardGeneric("LD"))

setMethod("LD", "geneSet",    LD.geneSet)




geneSet2Ped2<-function (geneSetObject) 
{
    sampleInfo <- geneSetObject@sampleInfo
    len <- ncol(sampleInfo)
    if(len<1) {
        stop("`sampleInfo' must include at least 1 column")
    } 
    columns <- colnames(sampleInfo)
    geneInfo <- alleleCodes(geneSetObject)
    ped <- cbind(as.matrix(sampleInfo), geneInfo)
    invisible(list(ped = ped, columns = columns))
}

alleleCodes <- function(obj, which=c(1, 2))
{
  retval <- alleles(obj,which=which, codes=TRUE)
  retval[is.na(retval)] <- 0
  retval
}
